pub enum LoadVarError<T: FromStr> {
VarError(VarError),
ParseError(T::Err),
IOError(Error),
}Expand description
Errors that can occur when loading a global config variable from the environment.
Variants
VarError(VarError)
Errors returned from std::env::var.
ParseError(T::Err)
Environment variable had a value but it could not be parsed.
IOError(Error)
Errors returned from std::fs::File::open.